@@ -2,12 +2,17 @@
 
 PERL=${PREFIX}/bin/perl
 declare -a _CONFIG_OPTS
-_CONFIG_OPTS+=(--prefix=${PREFIX})
 _CONFIG_OPTS+=(--libdir=lib)
-_CONFIG_OPTS+=(shared)
-_CONFIG_OPTS+=(threads)
+_CONFIG_OPTS+=(--prefix=${PREFIX})
+_CONFIG_OPTS+=(enable-fips)
 _CONFIG_OPTS+=(enable-ssl2)
 _CONFIG_OPTS+=(no-zlib)
+_CONFIG_OPTS+=(shared)
+_CONFIG_OPTS+=(threads)
+
+if [[ "$target_platform" = "linux-"* ]]; then
+  _CONFIG_OPTS+=(enable-ktls)
+fi
 
 # We are cross-compiling or using a specific compiler.
 # do not allow config to make any guesses based on uname.
@@ -36,8 +41,12 @@ esac
 CC=${CC}" ${CPPFLAGS} ${CFLAGS}" \
   ${_CONFIGURATOR} ${_CONFIG_OPTS[@]} ${LDFLAGS}
 
+# specify in metadata where the packaging is coming from
+export OPENSSL_VERSION_BUILD_METADATA="+fips+conda_forge"
+
 make -j${CPU_COUNT}
 
 if [[ "${CONDA_BUILD_CROSS_COMPILATION}" != "1" ]]; then
+  echo "Running tests"
   make test
 fi
